# Generated by Django 6.0.1 on 2026-01-20 13:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ldap', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ldapuser',
            name='created_at',
            field=models.DateField(auto_now_add=True),
        ),
        migrations.AlterField(
            model_name='ldapuser',
            name='updated_at',
            field=models.DateField(auto_now=True),
        ),
    ]
